:orphan:

Images and Logos
================

Here are some commonly used Dask icons and logos
(see the `Dask style guide <https://www.dask.org/style-guide>`_ for more details).

.. image:: images/dask_icon.svg
   :alt: Primary Dask icon.

.. image:: images/dask_icon_black.svg
   :alt: Dask icon in black.

.. image:: images/dask_icon_white.svg
   :alt: Dask icon in white.

.. image:: images/dask_icon_on_pink.svg
   :alt: Dask icon to use on a pink background.

.. image:: images/dask_horizontal.svg
   :alt: Primary Dask logo.

.. image:: images/dask_horizontal_black.svg
   :alt: Dask logo in black.

.. image:: images/dask_horizontal_white.svg
   :alt: Dask logo in white.

.. image:: images/dask_horizontal_on_pink.svg
   :alt: Dask logo to use on a pink background.

.. image:: images/dask_horizontal_on_blue.svg
   :alt: Dask logo to use on a blue background.
